@@ -3,23 +3,31 @@ from .common import build_url, pretty_print
 
 
 class API:
-    def __init__(self, endpoint, search=None, resource=None):
+    def __init__(self, endpoint=None, search=None, resource=None, object=False, data=None):
         self.endpoint = endpoint
         self.search = search
         self.resource = resource
-        self.url = build_url(endpoint, search, resource)
-        self.load()
+        self.object = object
+        if endpoint is not None:
+            self.url = build_url(endpoint, search, resource)
+        if not object:
+            self.__load()
+        else:
+            self.__dict__.update(data)
+
 
     def __repr__(self):
-        return f"API(endpoint={self.endpoint}, resource_id={self.resource})"
+        if self.object:
+            return f"API(object={self.__dict__})"
+        if self.resource is not None:
+            return f"API(endpoint='{self.endpoint}', search='{self.search}', resource='{self.resource}', url='{self.url}')"
+        if self.search is not None:
+            return f"API(endpoint='{self.endpoint}', search='{self.search}', url='{self.url}')"
+        return f"API(endpoint='{self.endpoint}', url='{self.url}')"
 
     def __str__(self):
-        if getattr(self, "results", None) is not None:
-            for result in self.results:
-                print(pretty_print(result))
-            return ""
         if getattr(self, "count", None) is not None:
-            return f"Total {self.endpoint} found: {self.count}"
+            return f"Total {self.endpoint} found for this search: {self.count}.\nTo see the results, iterate over the object."
         return pretty_print(self.__dict__)
 
     def __iter__(self):
@@ -37,12 +45,12 @@ class API:
             return self.count
         raise TypeError(f"Object of type {type(self)} has no len() for unique result")
 
-    def load(self):
+    def __load(self):
         api_data = get_data(self.url)
         if api_data is None:
             raise ValueError(f"No data found for the given search:{self.search} and resource_id:{self.resource}")
         elif isinstance(api_data, list) and len(api_data) > 1:
-            self.results = api_data
+            self.results = [API(object=True, data=result) for result in api_data]
             self.count = len(api_data)
         elif isinstance(api_data, list) and len(api_data) == 1:
             self.__dict__.update(api_data[0])
